<p align="center">
  <a href="https://py-contributors.github.io/audiobook/"><img src="https://capsule-render.vercel.app/api?type=rect&color=009ACD&height=100&section=header&text=audioBook&fontSize=80%&fontColor=ffffff" alt="website title image"></a>
  <h2 align="center">👉 CLI tool to listen to your favourite book in Python 👈</h2>
</p>

<p align="center">
<img src="https://img.shields.io/badge/Python-3.8.5-lightgrey?style=for-the-badge" alt="repo language">
<a href="https://github.com/py-contributors/audiobook/stargazers"><img src="https://img.shields.io/github/stars/py-contributors/audiobook?style=for-the-badge" alt="github stars"></a>
<a href="https://github.com/py-contributors/audiobook/network/members"><img src="https://img.shields.io/github/forks/py-contributors/audiobook?style=for-the-badge" alt="github forks"></a>
<img src="https://img.shields.io/github/languages/code-size/py-contributors/audiobook?style=for-the-badge" alt="code size">
  </p>
  <p align="center">
<a href="https://pypi.org/project/audiobook/"><img src="https://img.shields.io/pypi/status/audiobook.svg?style=for-the-badge" alt="pypi status"></a>
<a href="https://pypi.org/project/audiobook/"><img src="https://img.shields.io/pypi/dm/audiobook?style=for-the-badge" alt="download"></a>
<a href="https://pypi.org/project/audiobook/"><img src="https://img.shields.io/readthedocs/audiobook?style=for-the-badge" alt="docs"></a>
<a href="https://pypi.org/project/audiobook/"><img src="https://img.shields.io/librariesio/release/pypi/audiobook?style=for-the-badge" alt="dependices"></a>
</p>
<p align="center">
<a href="https://discord.gg/JfbK3bS"><img src="https://img.shields.io/discord/758030555005714512.svg?label=Discord&logo=Discord&colorB=7289da&style=for-the-badge" alt="discord invite"></a>
<a href="https://api.github.com/repos/py-contributors/audiobook/contributors"><img src="https://img.shields.io/github/contributors/py-contributors/audiobook?style=for-the-badge" alt="total contributors"></a>
</p>

## Installation

Install using [pypi](https://pypi.org/project/audiobook/)

### Using pip

```cmd
pip install audiobook
```

## Documentation

Check the full documentation here:- [Read the docs](https://pycontributors.readthedocs.io/projects/Audiobook/en/latest/)


## Supported File Formats

| File Format | Supported | Engine |
| :--- | :---: | :---: |
| PDF | ✅ | pypdf2/pdfminor |
| TXT | ✅ |  not required  |
| EPUB | ✅ | not required  |
| MOBI | ✅ | not required  |
| HTML | ✅ | not required  |
| DOCX | ✅ | not required  |
| ODT | ✅ | not required  |

## Changelog and Release Notes

Check the changelog and release notes [here](/CHANGELOG.md)

## Contributors

<a href="https://github.com/Py-Contributors/audiobook/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=Py-Contributors/audiobook"/>
</a>
